==> racer-0.1.1.tgz: package/lib/Promise.js <==
var Promise;
var __slice = Array.prototype.slice;
Promise = module.exports = function() {
  this.callbacks = [];
  this.clearValueCallbacks = [];
};
Promise.prototype = {
  on: function(callback, scope) {
    if (this.value !== void 0) {
      return callback.call(scope, this.value);
    }
    this.callbacks.push([callback, scope]);
    return this;
  },
  fulfill: function(val) {
    var callback, scope, _i, _len, _ref, _ref2;
    if (this.value !== void 0) {
      throw new Error('Promise has already been fulfilled');
    }
    this.value = val;
    _ref = this.callbacks;
    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
      _ref2 = _ref[_i], callback = _ref2[0], scope = _ref2[1];
      callback.call(scope, val);
    }
    this.callbacks = [];
    return this;
  },
  onClearValue: function(callback, scope) {
    this.clearValueCallbacks.push([callback, scope]);
    return this;
  },
  clearValue: function() {
    var callback, cbs, scope, _i, _len, _ref;
    delete this.value;
    cbs = this.clearValueCallbacks;
    for (_i = 0, _len = cbs.length; _i < _len; _i++) {
      _ref = cbs[_i], callback = _ref[0], scope = _ref[1];
      callback.call(scope);
    }
    this.clearValueCallbacks = [];
    return this;
  }
};
Promise.parallel = function() {
  var compositePromise, dependencies, promise, promises, _i, _len;
  promises = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
  compositePromise = new Promise;
  dependencies = promises.length;
  for (_i = 0, _len = promises.length; _i < _len; _i++) {
    promise = promises[_i];
    promise.on(function() {
      return --dependencies || compositePromise.fulfill(true);
    });
    promise.onClearValue(function() {
      return compositePromise.clearValue();
    });
  }
  return compositePromise;
};

==> racer-0.1.3.tgz: package/lib/Promise.js <==
var Promise;
var __slice = Array.prototype.slice;

Promise = module.exports = function() {
  this.callbacks = [];
  this.clearValueCallbacks = [];
};

Promise.prototype = {
  on: function(callback, scope) {
    if (this.value !== void 0) return callback.call(scope, this.value);
    this.callbacks.push([callback, scope]);
    return this;
  },
  fulfill: function(val) {
    var callback, scope, _i, _len, _ref, _ref2;
    if (this.value !== void 0) {
      throw new Error('Promise has already been fulfilled');
    }
    this.value = val;
    _ref = this.callbacks;
    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
      _ref2 = _ref[_i], callback = _ref2[0], scope = _ref2[1];
      callback.call(scope, val);
    }
    this.callbacks = [];
    return this;
  },
  onClearValue: function(callback, scope) {
    this.clearValueCallbacks.push([callback, scope]);
    return this;
  },
  clearValue: function() {
    var callback, cbs, scope, _i, _len, _ref;
    delete this.value;
    cbs = this.clearValueCallbacks;
    for (_i = 0, _len = cbs.length; _i < _len; _i++) {
      _ref = cbs[_i], callback = _ref[0], scope = _ref[1];
      callback.call(scope);
    }
    this.clearValueCallbacks = [];
    return this;
  }
};

Promise.parallel = function() {
  var compositePromise, dependencies, promise, promises, _i, _len;
  promises = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
  compositePromise = new Promise;
  dependencies = promises.length;
  for (_i = 0, _len = promises.length; _i < _len; _i++) {
    promise = promises[_i];
    promise.on(function() {
      return --dependencies || compositePromise.fulfill(true);
    });
    promise.onClearValue(function() {
      return compositePromise.clearValue();
    });
  }
  return compositePromise;
};
